# django_autodemo/apps.py
# django_autodemo
# Author: Rushy Panchal
# Date: April 20th, 2017
# Description: App configuration for Django.

from django.apps import AppConfig

class WsseConfig(AppConfig):
	name = 'django_autodemo'
